==> bootFacebookAccountCreator-1.8.0.tar.gz: bootFacebookAccountCreator-1.8.0/setup.py <==
from setuptools import setup, find_packages

install_requires = ["aiosqlite==0.17.0",
        "async-timeout==4.0.3",
        "asyncpg==0.29.0",
        "attrs==23.1.0",
        "certifi==2023.11.17",
        "charset-normalizer==3.3.2",
        "exceptiongroup==1.2.0",
        "fake-useragent==1.4.0",
        "Faker==20.1.0",
        "Genderize==0.3.1",
        "greenlet==3.0.2",
        "h11==0.14.0",
        "idna==3.6",
        "importlib-resources==6.1.1",
        "iso8601==1.1.0",
        "numpy==1.26.2",
        "outcome==1.3.0.post0",
        "packaging==23.2",
        "pandas==2.1.4",
        "psycopg==3.1.13",
        "psycopg-binary==3.1.13",
        "psycopg-pool==3.2.0",
        "psycopg2-binary==2.9.9",
        "pypika-tortoise==0.1.6",
        "PySocks==1.7.1",
        "python-dateutil==2.8.2",
        "python-dotenv==1.0.0",
        "pytz==2023.3.post1",
        "requests==2.31.0",
        "selenium==4.15.2",
        "selenium-stealth==1.0.6",
        "six==1.16.0",
        "sniffio==1.3.0",
        "sortedcontainers==2.4.0",
        "SQLAlchemy==2.0.23",
        "tortoise-orm==0.20.0",
        "trio==0.23.1",
        "trio-websocket==0.11.1",
        "typing-extensions==4.8.0",
        "tzdata==2023.3",
        "undetected-chromedriver==3.5.4",
        "urllib3==2.1.0",
        "useragent==0.1.1",
        "webdriver-manager==4.0.1",
        "websockets==12.0",
        "wsproto==1.2.0",
        "zipp==3.17.0",]


setup(
        name="bootFacebookAccountCreator",
        version="1.8.0",
        packages=find_packages(),
        install_requires=install_requires,
        package_data={'bootFacebookAccountCreator': ['chromedriver']},
        data_files=[('bootFacebookAccountCreator', ['bootFacebookAccountCreator/chromedriver'])],
        author="milerlite"
)

==> bootFacebookAccountCreator-1.10.0.tar.gz: bootFacebookAccountCreator-1.10.0/setup.py <==
from setuptools import setup, find_packages

install_requires = ["aiosqlite==0.17.0",
        "async-timeout==4.0.3",
        "asyncpg==0.29.0",
        "attrs==23.1.0",
        "certifi==2023.11.17",
        "charset-normalizer==3.3.2",
        "exceptiongroup==1.2.0",
        "fake-useragent==1.4.0",
        "Faker==20.1.0",
        "Genderize==0.3.1",
        "greenlet==3.0.2",
        "h11==0.14.0",
        "idna==3.6",
        "importlib-resources==6.1.1",
        "iso8601==1.1.0",
        "numpy==1.26.2",
        "outcome==1.3.0.post0",
        "packaging==23.2",
        "pandas==2.1.4",
        "psycopg==3.1.13",
        "psycopg-binary==3.1.13",
        "psycopg-pool==3.2.0",
        "psycopg2-binary==2.9.9",
        "pypika-tortoise==0.1.6",
        "PySocks==1.7.1",
        "python-dateutil==2.8.2",
        "python-dotenv==1.0.0",
        "pytz==2023.3.post1",
        "requests==2.31.0",
        "selenium==4.15.2",
        "selenium-stealth==1.0.6",
        "six==1.16.0",
        "sniffio==1.3.0",
        "sortedcontainers==2.4.0",
        "SQLAlchemy==2.0.23",
        "tortoise-orm==0.20.0",
        "trio==0.23.1",
        "trio-websocket==0.11.1",
        "typing-extensions==4.8.0",
        "tzdata==2023.3",
        "undetected-chromedriver==3.5.4",
        "urllib3==2.1.0",
        "useragent==0.1.1",
        "webdriver-manager==4.0.1",
        "websockets==12.0",
        "wsproto==1.2.0",
        "zipp==3.17.0",]


setup(
        name="bootFacebookAccountCreator",
        version="1.10.0",
        packages=find_packages(include=['chromedriver', 'chromedriver.*']
),
        install_requires=install_requires,
        package_data={'src': ['chromedriver']},
        data_files=[('src', ['src/chromedriver'])],
        author="milerlite"
)
